summaryrefslogtreecommitdiffstats
path: root/kbarcode
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:59:42 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:59:42 -0600
commit05f8ba84ce33da849bceb4c068a58711fe40b5d4 (patch)
treef12f9e37994fcb21fca1488742a8324180e99a96 /kbarcode
parentf1f618c34b558cbb9edf5ed4c2f4636b4b9c630e (diff)
downloadkbarcode-05f8ba84ce33da849bceb4c068a58711fe40b5d4.tar.gz
kbarcode-05f8ba84ce33da849bceb4c068a58711fe40b5d4.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kbarcode')
-rw-r--r--kbarcode/barcodedialog.h6
-rw-r--r--kbarcode/batchwizard.cpp18
-rw-r--r--kbarcode/batchwizard.h12
-rw-r--r--kbarcode/csvimportdlg.cpp2
-rw-r--r--kbarcode/csvimportdlg.h2
-rw-r--r--kbarcode/databasebrowser.cpp12
-rw-r--r--kbarcode/databasebrowser.h12
-rw-r--r--kbarcode/dsmainwindow.cpp28
-rw-r--r--kbarcode/dsmainwindow.h18
-rw-r--r--kbarcode/kactionmap.cpp44
-rw-r--r--kbarcode/kactionmap.h30
-rw-r--r--kbarcode/kbarcode.cpp12
-rw-r--r--kbarcode/kbarcode.h4
-rw-r--r--kbarcode/labeleditor.cpp78
-rw-r--r--kbarcode/labeleditor.h94
-rw-r--r--kbarcode/multilineeditdlg.cpp44
-rw-r--r--kbarcode/multilineeditdlg.h36
-rw-r--r--kbarcode/textlineedit.cpp20
-rw-r--r--kbarcode/textlineedit.h18
-rw-r--r--kbarcode/tokendialog.cpp16
-rw-r--r--kbarcode/tokendialog.h12
21 files changed, 259 insertions, 259 deletions
diff --git a/kbarcode/barcodedialog.h b/kbarcode/barcodedialog.h
index ff1c255..691786a 100644
--- a/kbarcode/barcodedialog.h
+++ b/kbarcode/barcodedialog.h
@@ -22,14 +22,14 @@
class BarcodeCombo;
class BarcodeWidget;
-class KAction;
+class TDEAction;
class KColorButton;
class KMenuBar;
-class KToolBar;
+class TDEToolBar;
class KIntNumInput;
class KLineEdit;
class KPushButton;
-class KPopupMenu;
+class TDEPopupMenu;
class TQCheckBox;
class TQLabel;
class TQPixmap;
diff --git a/kbarcode/batchwizard.cpp b/kbarcode/batchwizard.cpp
index d71104e..17193a3 100644
--- a/kbarcode/batchwizard.cpp
+++ b/kbarcode/batchwizard.cpp
@@ -66,10 +66,10 @@
#define PNG_FORMAT "PNG"
-class AddressListViewItem : public KListViewItem {
+class AddressListViewItem : public TDEListViewItem {
public:
AddressListViewItem(TQListView *parent, KABC::Addressee & addr )
- : KListViewItem( parent ), m_address( addr )
+ : TDEListViewItem( parent ), m_address( addr )
{
this->setText( 0, m_address.givenName() );
this->setText( 1, m_address.familyName() );
@@ -308,13 +308,13 @@ void BatchWizard::setupStackPage1()
buttonRemove = new KPushButton( i18n("&Remove" ), hButtonBox );
buttonRemoveAll = new KPushButton( i18n("R&emove All"), hButtonBox );
- KPopupMenu* mnuImport = new KPopupMenu( this );
+ TDEPopupMenu* mnuImport = new TDEPopupMenu( this );
mnuImport->insertItem( i18n("Import from File ..."), this, TQT_SLOT( loadFromFile() ) );
mnuImport->insertItem( i18n("Import from Clipboard ..."), this, TQT_SLOT( loadFromClipboard() ) );
mnuImport->insertItem( i18n("Import barcode_basic"), this, TQT_SLOT( addAllItems() ) );
buttonImport->setPopup( mnuImport );
- sqlList = new KListView( stack1 );
+ sqlList = new TDEListView( stack1 );
sqlList->addColumn( i18n("Index") );
sqlList->addColumn( i18n("Number of Labels") );
sqlList->addColumn( i18n("Article Number") );
@@ -360,7 +360,7 @@ void BatchWizard::setupStackPage2()
box->setSpacing( 5 );
new TQLabel( i18n("Available Variables:"), box );
- m_varList = new KListBox( box );
+ m_varList = new TDEListBox( box );
connect( radioImportManual, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
connect( radioImportSql, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
@@ -430,7 +430,7 @@ void BatchWizard::setupStackPage4()
new TQLabel( i18n("All Addresses"), list1 );
new TQLabel( i18n("Selected Addresses"), list2 );
- listAddress = new KListView( list1 );
+ listAddress = new TDEListView( list1 );
listAddress->addColumn( i18n("Given Name"), 0 );
listAddress->addColumn( i18n("Family Name"), 1 );
listAddress->addColumn( i18n("Email Address"), 2 );
@@ -441,7 +441,7 @@ void BatchWizard::setupStackPage4()
listAddress->setColumnWidthMode( 1, TQListView::Maximum );
listAddress->setColumnWidthMode( 2, TQListView::Maximum );
- listSelectedAddress = new KListView( list2 );
+ listSelectedAddress = new TDEListView( list2 );
listSelectedAddress->addColumn( i18n("Given Name"), 0 );
listSelectedAddress->addColumn( i18n("Family Name"), 1 );
listSelectedAddress->addColumn( i18n("Email Address"), 2 );
@@ -747,7 +747,7 @@ bool BatchWizard::addItem( const TQString & article, const TQString & group, int
TQString temp;
temp.sprintf("%0*i", 5, sqlList->childCount() + 1 );
- KListViewItem* item = new KListViewItem( sqlList, temp, TQString( "%1" ).arg( count ),
+ TDEListViewItem* item = new TDEListViewItem( sqlList, temp, TQString( "%1" ).arg( count ),
article, group );
sqlList->insertItem( item );
@@ -857,7 +857,7 @@ void BatchWizard::addAllItems()
while( query.next() )
{
temp.sprintf("%0*i", 5, sqlList->childCount() + 1 );
- new KListViewItem( sqlList, temp, num, query.value( 0 ).toString(), group );
+ new TDEListViewItem( sqlList, temp, num, query.value( 0 ).toString(), group );
}
enableControls();
diff --git a/kbarcode/batchwizard.h b/kbarcode/batchwizard.h
index a4233ea..3bc18e1 100644
--- a/kbarcode/batchwizard.h
+++ b/kbarcode/batchwizard.h
@@ -27,8 +27,8 @@ class KComboBox;
class KCompletion;
class KIntNumInput;
class KLineEdit;
-class KListBox;
-class KListView;
+class TDEListBox;
+class TDEListView;
class KPushButton;
class KURLRequester;
class TQCheckBox;
@@ -237,12 +237,12 @@ class BatchWizard : public KWizard, public BatchIface {
KIntNumInput* numLabels;
TQTable* m_varTable;
- KListBox* m_varList;
+ TDEListBox* m_varList;
- KListView* listAddress;
- KListView* listSelectedAddress;
+ TDEListView* listAddress;
+ TDEListView* listSelectedAddress;
- KListView* sqlList;
+ TDEListView* sqlList;
KLineEdit* serialStart;
TQCheckBox* checkKeepOpen;
diff --git a/kbarcode/csvimportdlg.cpp b/kbarcode/csvimportdlg.cpp
index 99e3603..017bb02 100644
--- a/kbarcode/csvimportdlg.cpp
+++ b/kbarcode/csvimportdlg.cpp
@@ -201,7 +201,7 @@ void CSVImportDlg::createPage2()
TQHBoxLayout* groupFixedLayout = new TQHBoxLayout( groupFixed->layout() );
groupFixedLayout->setAlignment( TQt::AlignTop );
- listWidth = new KListBox( groupFixed );
+ listWidth = new TDEListBox( groupFixed );
buttonAdd = new KPushButton( groupFixed );
buttonAdd->setText( i18n( "&Add Field" ) );
diff --git a/kbarcode/csvimportdlg.h b/kbarcode/csvimportdlg.h
index b4cec6f..8c884d5 100644
--- a/kbarcode/csvimportdlg.h
+++ b/kbarcode/csvimportdlg.h
@@ -113,7 +113,7 @@ class CSVImportDlg : public KDialogBase {
TQGroupBox* groupCSV;
TQGroupBox* groupFixed;
- KListBox* listWidth;
+ TDEListBox* listWidth;
KPushButton* buttonAdd;
KPushButton* buttonRemove;
KIntNumInput* spinNumber;
diff --git a/kbarcode/databasebrowser.cpp b/kbarcode/databasebrowser.cpp
index 1490cc5..7637201 100644
--- a/kbarcode/databasebrowser.cpp
+++ b/kbarcode/databasebrowser.cpp
@@ -79,12 +79,12 @@ DatabaseBrowser::~DatabaseBrowser()
void DatabaseBrowser::setupActions()
{
DSMainWindow::setupActions();
- KPopupMenu* editMenu = new KPopupMenu( this );
+ TDEPopupMenu* editMenu = new TDEPopupMenu( this );
- KAction* acut = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection() );
- KAction* acopy = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection() );
- KAction* apaste = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection() );
- KAction* afind = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT( find() ), actionCollection() );
+ TDEAction* acut = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection() );
+ TDEAction* acopy = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection() );
+ TDEAction* apaste = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection() );
+ TDEAction* afind = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT( find() ), actionCollection() );
menuBar()->insertItem( i18n("&Edit"), editMenu, -1, 1 );
acut->plug( editMenu );
@@ -95,7 +95,7 @@ void DatabaseBrowser::setupActions()
afind->plug( editMenu );
KStdAction::findNext( TQT_TQOBJECT(this), TQT_SLOT( findNext() ), actionCollection() )->plug( editMenu );
editMenu->insertSeparator();
- KAction* aimport = new KAction( i18n("&Import CSV File..."), "",
+ TDEAction* aimport = new TDEAction( i18n("&Import CSV File..."), "",
0, TQT_TQOBJECT(this), TQT_SLOT(import()), actionCollection(), "import" );
aimport->plug( editMenu );
diff --git a/kbarcode/databasebrowser.h b/kbarcode/databasebrowser.h
index 32592d2..d6230f5 100644
--- a/kbarcode/databasebrowser.h
+++ b/kbarcode/databasebrowser.h
@@ -20,12 +20,12 @@
#include "dsmainwindow.h"
-class KAction;
+class TDEAction;
class KEdFind;
class KMenuBar;
-class KToolBar;
+class TDEToolBar;
class KPushButton;
-class KPopupMenu;
+class TDEPopupMenu;
class MyDataTable;
/** A database browser widget. Allows small changes to SQL tables
* and is mostly used for having a quick look on the tables.
@@ -56,9 +56,9 @@ class DatabaseBrowser : public DSMainWindow{
TQString database;
MyDataTable* table;
- KAction* undoAct;
- KAction* deleteAct;
- KAction* newAct;
+ TDEAction* undoAct;
+ TDEAction* deleteAct;
+ TDEAction* newAct;
KEdFind* findDlg;
diff --git a/kbarcode/dsmainwindow.cpp b/kbarcode/dsmainwindow.cpp
index 04205d8..451256d 100644
--- a/kbarcode/dsmainwindow.cpp
+++ b/kbarcode/dsmainwindow.cpp
@@ -44,7 +44,7 @@ bool DSMainWindow::autoconnect = true;
bool DSMainWindow::startwizard = true;
DSMainWindow::DSMainWindow(TQWidget *parent, const char *name, WFlags f)
- : KMainWindow(parent,name,f)
+ : TDEMainWindow(parent,name,f)
{
connectAct = 0;
first = false;
@@ -66,27 +66,27 @@ DSMainWindow::~DSMainWindow()
void DSMainWindow::setupActions()
{
- KAction* quitAct = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
- KAction* closeAct = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection(), "close" );
- KAction* configureAct = KStdAction::preferences( KBarcodeSettings::getInstance(), TQT_SLOT(configure()), actionCollection() );
- KAction* wizardAct = new KAction( i18n("&Start Configuration Wizard..."), BarIcon("wizard"), 0, TQT_TQOBJECT(this),
+ TDEAction* quitAct = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
+ TDEAction* closeAct = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection(), "close" );
+ TDEAction* configureAct = KStdAction::preferences( KBarcodeSettings::getInstance(), TQT_SLOT(configure()), actionCollection() );
+ TDEAction* wizardAct = new TDEAction( i18n("&Start Configuration Wizard..."), BarIcon("wizard"), 0, TQT_TQOBJECT(this),
TQT_SLOT(wizard()), actionCollection(), "wizard" );
- connectAct = new KAction(i18n("&Connect to Database"), BarIcon("connect_no"), 0, TQT_TQOBJECT(this), TQT_SLOT(connectMySQL()),
+ connectAct = new TDEAction(i18n("&Connect to Database"), BarIcon("connect_no"), 0, TQT_TQOBJECT(this), TQT_SLOT(connectMySQL()),
actionCollection(),"connect" );
- KAction* newTablesAct = new KAction( i18n("&Create Tables"), "", 0, TQT_TQOBJECT(this),
+ TDEAction* newTablesAct = new TDEAction( i18n("&Create Tables"), "", 0, TQT_TQOBJECT(this),
TQT_SLOT(newTables()), actionCollection(), "tables" );
- importLabelDefAct = new KAction( i18n("&Import Label Definitions"), "", 0, SqlTables::getInstance(),
+ importLabelDefAct = new TDEAction( i18n("&Import Label Definitions"), "", 0, SqlTables::getInstance(),
TQT_SLOT(importLabelDef()), actionCollection(), "import" );
- importExampleAct = new KAction( i18n("&Import Example Data"), "", 0, SqlTables::getInstance(),
+ importExampleAct = new TDEAction( i18n("&Import Example Data"), "", 0, SqlTables::getInstance(),
TQT_SLOT(importExampleData()), actionCollection(), "import" );
- KPopupMenu* file = new KPopupMenu( this );
- KPopupMenu* settings = new KPopupMenu( this );
- KPopupMenu* hlpMenu = helpMenu();
+ TDEPopupMenu* file = new TDEPopupMenu( this );
+ TDEPopupMenu* settings = new TDEPopupMenu( this );
+ TDEPopupMenu* hlpMenu = helpMenu();
int helpid = hlpMenu->idAt( 0 );
hlpMenu->removeItem( helpid );
hlpMenu->insertItem( SmallIconSet("contents"), i18n("&Help"),
@@ -108,7 +108,7 @@ void DSMainWindow::setupActions()
configureAct->plug( settings );
wizardAct->plug( settings );
connectAct->plug( settings );
- (new KActionSeparator( TQT_TQOBJECT(this) ))->plug( settings );
+ (new TDEActionSeparator( TQT_TQOBJECT(this) ))->plug( settings );
newTablesAct->plug( settings );
importLabelDefAct->plug( settings );
importExampleAct->plug( settings );
@@ -262,7 +262,7 @@ TQString DSMainWindow::systemCheck()
void DSMainWindow::slotFunctionMap()
{
- new KActionMapDlg( actionCollection(), this );
+ new TDEActionMapDlg( actionCollection(), this );
}
#include "dsmainwindow.moc"
diff --git a/kbarcode/dsmainwindow.h b/kbarcode/dsmainwindow.h
index 1622c13..4eda407 100644
--- a/kbarcode/dsmainwindow.h
+++ b/kbarcode/dsmainwindow.h
@@ -21,8 +21,8 @@
#include <tqwidget.h>
#include <kmainwindow.h>
-class KAction;
-class KPopupMenu;
+class TDEAction;
+class TDEPopupMenu;
/** The base class of all main windows of KBarcode. It provides standard menu items
* for database connections, preferences, help, the first start wizard and donations.
* It checks also if this is the first start of KBarcode and if the configuration wizard
@@ -30,7 +30,7 @@ class KPopupMenu;
*
* @author Dominik Seichter
*/
-class DSMainWindow : public KMainWindow {
+class DSMainWindow : public TDEMainWindow {
Q_OBJECT
public:
@@ -80,12 +80,12 @@ class DSMainWindow : public KMainWindow {
bool first;
- KAction* connectAct;
- KAction* importLabelDefAct;
- KAction* importExampleAct;
+ TDEAction* connectAct;
+ TDEAction* importLabelDefAct;
+ TDEAction* importExampleAct;
- KPopupMenu* file;
- KPopupMenu* settings;
- KPopupMenu* hlpMenu;
+ TDEPopupMenu* file;
+ TDEPopupMenu* settings;
+ TDEPopupMenu* hlpMenu;
};
#endif
diff --git a/kbarcode/kactionmap.cpp b/kbarcode/kactionmap.cpp
index ae70698..ca7f396 100644
--- a/kbarcode/kactionmap.cpp
+++ b/kbarcode/kactionmap.cpp
@@ -35,10 +35,10 @@
#endif
#include <klocale.h>
-class KListViewActionItem : public KListViewItem {
+class TDEListViewActionItem : public TDEListViewItem {
public:
- KListViewActionItem( KListView* parent, KAction* action )
- : KListViewItem( parent ), m_action( action )
+ TDEListViewActionItem( TDEListView* parent, TDEAction* action )
+ : TDEListViewItem( parent ), m_action( action )
{
TQPixmap pix;
TQSize size = TQIconSet::iconSize( TQIconSet::Large );
@@ -74,43 +74,43 @@ public:
if( m_action && !m_action->isEnabled() )
_cg.setColor( TQColorGroup::Text, TQt::gray );
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ TDEListViewItem::paintCell( p, _cg, column, width, alignment );
_cg.setColor( TQColorGroup::Text, c );
}
- inline KAction* action() const
+ inline TDEAction* action() const
{
return m_action;
}
private:
- KAction* m_action;
+ TDEAction* m_action;
};
-KActionMapDlg::KActionMapDlg( KActionCollection* actions, TQWidget* parent, const char* name )
+TDEActionMapDlg::TDEActionMapDlg( TDEActionCollection* actions, TQWidget* parent, const char* name )
: KDialogBase( parent, name, false, i18n("Action Map"), KDialogBase::Close, KDialogBase::Close )
{
TQVBox *page = makeVBoxMainWidget();
new TQLabel( i18n("Find and execute actions."), page );
- m_map = new KActionMap( actions, page );
+ m_map = new TDEActionMap( actions, page );
show();
}
-void KActionMapDlg::updateEnabledState()
+void TDEActionMapDlg::updateEnabledState()
{
m_map->updateEnabledState();
}
-KActionMap::KActionMap( KActionCollection* actions, TQWidget* parent, const char* name )
+TDEActionMap::TDEActionMap( TDEActionCollection* actions, TQWidget* parent, const char* name )
: TQWidget( parent, name ), m_actions( actions ), m_showMenuTree( true ), m_grayOutItems( false )
{
TQVBoxLayout* layout = new TQVBoxLayout( this );
- m_listView = new KListView( this );
+ m_listView = new TDEListView( this );
#if TDE_VERSION >= 0x030500
- m_searchLine = new KListViewSearchLineWidget( m_listView, this );
+ m_searchLine = new TDEListViewSearchLineWidget( m_listView, this );
#endif
m_listView->addColumn( i18n("Action") );
@@ -128,20 +128,20 @@ KActionMap::KActionMap( KActionCollection* actions, TQWidget* parent, const char
layout->addWidget( m_listView );
connect( m_listView, TQT_SIGNAL( executed( TQListViewItem* ) ), this, TQT_SLOT( slotExecuteAction( TQListViewItem* ) ) );
- connect( actions, TQT_SIGNAL( inserted( KAction* ) ), this, TQT_SLOT( slotActionCollectionChanged() ) );
- connect( actions, TQT_SIGNAL( removed( KAction* ) ), this, TQT_SLOT( slotActionCollectionChanged() ) );
+ connect( actions, TQT_SIGNAL( inserted( TDEAction* ) ), this, TQT_SLOT( slotActionCollectionChanged() ) );
+ connect( actions, TQT_SIGNAL( removed( TDEAction* ) ), this, TQT_SLOT( slotActionCollectionChanged() ) );
slotActionCollectionChanged();
}
-KActionMap::~KActionMap()
+TDEActionMap::~TDEActionMap()
{
}
-void KActionMap::slotActionCollectionChanged()
+void TDEActionMap::slotActionCollectionChanged()
{
- KActionPtrList actions;
- KActionPtrList::const_iterator it;
+ TDEActionPtrList actions;
+ TDEActionPtrList::const_iterator it;
m_listView->clear();
@@ -159,7 +159,7 @@ void KActionMap::slotActionCollectionChanged()
}
*/
- new KListViewActionItem( m_listView, (*it) );
+ new TDEListViewActionItem( m_listView, (*it) );
connect( *it, TQT_SIGNAL( enabled(bool) ), this, TQT_SLOT( updateEnabledState() ) );
@@ -168,9 +168,9 @@ void KActionMap::slotActionCollectionChanged()
}
-void KActionMap::slotExecuteAction( TQListViewItem* item )
+void TDEActionMap::slotExecuteAction( TQListViewItem* item )
{
- KListViewActionItem* action = dynamic_cast<KListViewActionItem*>(item);
+ TDEListViewActionItem* action = dynamic_cast<TDEListViewActionItem*>(item);
if( !action )
return;
@@ -180,7 +180,7 @@ void KActionMap::slotExecuteAction( TQListViewItem* item )
action->action()->activate();
}
-void KActionMap::updateEnabledState()
+void TDEActionMap::updateEnabledState()
{
m_listView->repaintContents();
}
diff --git a/kbarcode/kbarcode.cpp b/kbarcode/kbarcode.cpp
index 9c7f6b8..1454a0b 100644
--- a/kbarcode/kbarcode.cpp
+++ b/kbarcode/kbarcode.cpp
@@ -72,22 +72,22 @@ KBarcode::KBarcode( TQWidget *parent, const char *name, WFlags f)
setupActions();
show();
- KAction* editLabelDefAct = new KAction(i18n("&Edit Label Definitions"), "",
+ TDEAction* editLabelDefAct = new TDEAction(i18n("&Edit Label Definitions"), "",
0, TQT_TQOBJECT(this), TQT_SLOT(editLabelDef()), actionCollection(), "design" );
- KAction* editArticleAct = new KAction(i18n("&Edit Articles"), "",
+ TDEAction* editArticleAct = new TDEAction(i18n("&Edit Articles"), "",
0, TQT_TQOBJECT(this), TQT_SLOT(editArticles()), actionCollection(), "design" );
- KAction* editCustomerAct = new KAction(i18n("&Edit Customers"), "",
+ TDEAction* editCustomerAct = new TDEAction(i18n("&Edit Customers"), "",
0, TQT_TQOBJECT(this), TQT_SLOT(editCustomers()), actionCollection(), "design" );
- KAction* editCustomerTextAct = new KAction(i18n("&Edit Customer Text"), "",
+ TDEAction* editCustomerTextAct = new TDEAction(i18n("&Edit Customer Text"), "",
0, TQT_TQOBJECT(this), TQT_SLOT(editCustomerText()), actionCollection() );
- KAction* importCSVAct = new KAction(i18n("&Import CSV File..."), "",
+ TDEAction* importCSVAct = new TDEAction(i18n("&Import CSV File..."), "",
0, TQT_TQOBJECT(this), TQT_SLOT(importCSV()), actionCollection() );
- KPopupMenu* data = new KPopupMenu( buttonData );
+ TDEPopupMenu* data = new TDEPopupMenu( buttonData );
editLabelDefAct->plug( data );
editArticleAct->plug( data );
editCustomerAct->plug( data );
diff --git a/kbarcode/kbarcode.h b/kbarcode/kbarcode.h
index 349b72f..e9bd6e8 100644
--- a/kbarcode/kbarcode.h
+++ b/kbarcode/kbarcode.h
@@ -35,7 +35,7 @@ enum linebreak {
#include "dsmainwindow.h"
#include "kbarcodeiface.h"
-class KAction;
+class TDEAction;
class KPushButton;
/** The main window of KBarcode. All submodules
* are started from here. Submodules are the LabelEditor
@@ -89,7 +89,7 @@ class KBarcode: public DSMainWindow, public KBarcodeIface {
void showConfigure();
- KAction* connectAct;
+ TDEAction* connectAct;
KPushButton* buttonSingle;
KPushButton* buttonEditor;
KPushButton* buttonBatch;
diff --git a/kbarcode/labeleditor.cpp b/kbarcode/labeleditor.cpp
index c4a1b51..2945266 100644
--- a/kbarcode/labeleditor.cpp
+++ b/kbarcode/labeleditor.cpp
@@ -226,8 +226,8 @@ void LabelEditor::createCommandHistory()
void LabelEditor::createCommandHistoryActions()
{
- undoAct = (KAction*)actionCollection()->action("edit_undo");
- redoAct = (KAction*)actionCollection()->action("edit_redo");
+ undoAct = (TDEAction*)actionCollection()->action("edit_undo");
+ redoAct = (TDEAction*)actionCollection()->action("edit_redo");
undoAct->plug( editMenu, 0 );
redoAct->plug( editMenu, 1 );
@@ -437,46 +437,46 @@ bool LabelEditor::newLabel()
void LabelEditor::setupActions()
{
- KAction* newAct = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT(startEditor()), actionCollection() );
- KAction* loadAct = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(startLoadEditor()), actionCollection() );
- KAction* quitAct = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
- KAction* closeAct = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection(), "close" );
- closeLabelAct = new KAction( i18n("Close &Label" ), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( closeLabel() ), actionCollection() );
+ TDEAction* newAct = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT(startEditor()), actionCollection() );
+ TDEAction* loadAct = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(startLoadEditor()), actionCollection() );
+ TDEAction* quitAct = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
+ TDEAction* closeAct = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection(), "close" );
+ closeLabelAct = new TDEAction( i18n("Close &Label" ), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( closeLabel() ), actionCollection() );
- recentAct = new KRecentFilesAction( i18n("&Recent Files"), 0, TQT_TQOBJECT(this), TQT_SLOT( loadRecentEditor( const KURL& ) ) );
+ recentAct = new TDERecentFilesAction( i18n("&Recent Files"), 0, TQT_TQOBJECT(this), TQT_SLOT( loadRecentEditor( const KURL& ) ) );
- KAction* importPrintFileAct = new KAction( i18n("&Import and Print Batch File..."), BarIconSet( "fileprint" ), 0, TQT_TQOBJECT(this), TQT_SLOT( batchPrint() ), actionCollection() );
+ TDEAction* importPrintFileAct = new TDEAction( i18n("&Import and Print Batch File..."), BarIconSet( "fileprint" ), 0, TQT_TQOBJECT(this), TQT_SLOT( batchPrint() ), actionCollection() );
saveAct = KStdAction::save( TQT_TQOBJECT(this), TQT_SLOT( save() ), actionCollection(), "save" );
saveAsAct = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT( saveas() ), actionCollection(), "saveas" );
- descriptionAct = new KAction( i18n("&Change description..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(changeDes()), actionCollection() );
- deleteAct = new KAction( i18n("&Delete Object"), TQIconSet( BarIcon("editdelete") ), Key_Delete, TQT_TQOBJECT(cv), TQT_SLOT( deleteCurrent() ), actionCollection() );
- editPropAct = new KAction( i18n("&Properties..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( doubleClickedCurrent() ), actionCollection() );
+ descriptionAct = new TDEAction( i18n("&Change description..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(changeDes()), actionCollection() );
+ deleteAct = new TDEAction( i18n("&Delete Object"), TQIconSet( BarIcon("editdelete") ), Key_Delete, TQT_TQOBJECT(cv), TQT_SLOT( deleteCurrent() ), actionCollection() );
+ editPropAct = new TDEAction( i18n("&Properties..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( doubleClickedCurrent() ), actionCollection() );
printAct = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT( print() ), actionCollection(), "print" );
- bcpAct = new KAction( i18n("Print to &Barcode Printer..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( printBCP() ), actionCollection() );
- imgAct = new KAction( i18n("Print to &Image..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(printImage() ), actionCollection() );
- changeSizeAct = new KAction( i18n("&Change Label..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( changeSize() ), actionCollection() );
- barcodeAct = new KAction( i18n("Insert &Barcode"), TQIconSet( BarIcon("barcode") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertBarcode() ), actionCollection() );
+ bcpAct = new TDEAction( i18n("Print to &Barcode Printer..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( printBCP() ), actionCollection() );
+ imgAct = new TDEAction( i18n("Print to &Image..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(printImage() ), actionCollection() );
+ changeSizeAct = new TDEAction( i18n("&Change Label..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( changeSize() ), actionCollection() );
+ barcodeAct = new TDEAction( i18n("Insert &Barcode"), TQIconSet( BarIcon("barcode") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertBarcode() ), actionCollection() );
barcodeAct->setEnabled( Barkode::haveBarcode() );
- pictureAct = new KAction( i18n("Insert &Picture"), TQIconSet( BarIcon("inline_image") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertPicture() ), actionCollection() );
- textAct = new KAction( i18n("Insert &Text"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertText() ), actionCollection() );
- textDataAct = new KAction( i18n("Insert &Data Field"), TQIconSet( BarIcon("contents") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertDataText() ), actionCollection() );
- textLineAct = new KAction( i18n("Insert &Text Line"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertTextLine() ), actionCollection() );
- lineAct = new KAction( i18n("Insert &Line"), TQIconSet( BarIcon("kbarcodelinetool") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertLine() ), actionCollection() );
- rectAct = new KAction( i18n("Insert &Rectangle"), TQIconSet( BarIcon("kbarcoderect") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertRect() ), actionCollection() );
- circleAct = new KAction( i18n("Insert &Ellipse"), TQIconSet( BarIcon("kbarcodeellipse") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertCircle() ), actionCollection() );
+ pictureAct = new TDEAction( i18n("Insert &Picture"), TQIconSet( BarIcon("inline_image") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertPicture() ), actionCollection() );
+ textAct = new TDEAction( i18n("Insert &Text"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertText() ), actionCollection() );
+ textDataAct = new TDEAction( i18n("Insert &Data Field"), TQIconSet( BarIcon("contents") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertDataText() ), actionCollection() );
+ textLineAct = new TDEAction( i18n("Insert &Text Line"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertTextLine() ), actionCollection() );
+ lineAct = new TDEAction( i18n("Insert &Line"), TQIconSet( BarIcon("kbarcodelinetool") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertLine() ), actionCollection() );
+ rectAct = new TDEAction( i18n("Insert &Rectangle"), TQIconSet( BarIcon("kbarcoderect") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertRect() ), actionCollection() );
+ circleAct = new TDEAction( i18n("Insert &Ellipse"), TQIconSet( BarIcon("kbarcodeellipse") ), 0, TQT_TQOBJECT(this), TQT_SLOT( insertCircle() ), actionCollection() );
spellAct = KStdAction::spelling( TQT_TQOBJECT(this), TQT_SLOT(spellCheck()), actionCollection(), "spell" );
- gridAct = new KToggleAction( i18n("&Grid"), TQIconSet( BarIcon("kbarcodegrid") ), 0, TQT_TQOBJECT(this), TQT_SLOT( toggleGrid() ), actionCollection() );
- previewAct = new KAction( i18n("&Preview..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( preview() ), actionCollection() );
- sep = new KActionSeparator( TQT_TQOBJECT(this) );
+ gridAct = new TDEToggleAction( i18n("&Grid"), TQIconSet( BarIcon("kbarcodegrid") ), 0, TQT_TQOBJECT(this), TQT_SLOT( toggleGrid() ), actionCollection() );
+ previewAct = new TDEAction( i18n("&Preview..."), 0, 0, TQT_TQOBJECT(this), TQT_SLOT( preview() ), actionCollection() );
+ sep = new TDEActionSeparator( TQT_TQOBJECT(this) );
cutAct = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection(), "cut" );
copyAct = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection(), "copy" );
pasteAct = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection(), "paste" );
selectAllAct = KStdAction::selectAll( TQT_TQOBJECT(cv), TQT_SLOT( selectAll() ), actionCollection(), "select_all" );
deSelectAllAct = KStdAction::deselect( TQT_TQOBJECT(cv), TQT_SLOT( deSelectAll() ), actionCollection(), "de_select_all" );
- addressBookAct = new KAction( i18n("Address&book"), TQIconSet( BarIcon("kaddressbook") ), 0, TQT_TQOBJECT(this), TQT_SLOT( launchAddressBook() ), actionCollection() );
- KAction* singleBarcodeAct = new KAction(i18n("&Create Single Barcode..."), "",
+ addressBookAct = new TDEAction( i18n("Address&book"), TQIconSet( BarIcon("kaddressbook") ), 0, TQT_TQOBJECT(this), TQT_SLOT( launchAddressBook() ), actionCollection() );
+ TDEAction* singleBarcodeAct = new TDEAction(i18n("&Create Single Barcode..."), "",
0, TQT_TQOBJECT(this), TQT_SLOT(startBarcodeGen()),
actionCollection(), "create" );
singleBarcodeAct->setEnabled( Barkode::haveBarcode() );
@@ -490,7 +490,7 @@ void LabelEditor::setupActions()
copyAct->plug( toolBar() );
pasteAct->plug( toolBar() );
- tools = new KToolBar( this, this->leftDock(), true, "tools" );
+ tools = new TDEToolBar( this, this->leftDock(), true, "tools" );
barcodeAct->plug( tools );
pictureAct->plug( tools );
@@ -500,19 +500,19 @@ void LabelEditor::setupActions()
lineAct->plug( tools );
rectAct->plug( tools );
circleAct->plug( tools );
- (new KActionSeparator( TQT_TQOBJECT(this) ))->plug( tools );
+ (new TDEActionSeparator( TQT_TQOBJECT(this) ))->plug( tools );
// spellAct->plug( tools ); // KDE 3.2
gridAct->plug( tools );
DSMainWindow::setupActions();
connect( recentAct, TQT_SIGNAL( urlSelected( const KURL& ) ), TQT_TQOBJECT(this), TQT_SLOT( startLoadRecentEditor( const KURL& ) ) );
- KPopupMenu* fileMenu = new KPopupMenu( this );
- editMenu = new KPopupMenu( this );
- KPopupMenu* viewMenu = new KPopupMenu( this );
- KPopupMenu* insMenu = new KPopupMenu( this );
- KPopupMenu* toolMenu = new KPopupMenu( this );
- KPopupMenu* barMenu = new KPopupMenu( this );
+ TDEPopupMenu* fileMenu = new TDEPopupMenu( this );
+ editMenu = new TDEPopupMenu( this );
+ TDEPopupMenu* viewMenu = new TDEPopupMenu( this );
+ TDEPopupMenu* insMenu = new TDEPopupMenu( this );
+ TDEPopupMenu* toolMenu = new TDEPopupMenu( this );
+ TDEPopupMenu* barMenu = new TDEPopupMenu( this );
menuBar()->removeItemAt( 0 );
menuBar()->insertItem( i18n("&File"), fileMenu, -1, 0 );
@@ -575,16 +575,16 @@ void LabelEditor::setupActions()
void LabelEditor::setupContextMenu()
{
- m_mnuContext = new KPopupMenu( this );
+ m_mnuContext = new TDEPopupMenu( this );
m_mnuContext->setCheckable( true );
- KPopupMenu* orderMenu = new KPopupMenu( m_mnuContext );
+ TDEPopupMenu* orderMenu = new TDEPopupMenu( m_mnuContext );
orderMenu->insertItem( i18n("&On Top"), TQT_TQOBJECT(this), TQT_SLOT( onTopCurrent() ) );
orderMenu->insertItem( i18n("&Raise"), TQT_TQOBJECT(this), TQT_SLOT( raiseCurrent() ) );
orderMenu->insertItem( i18n("&Lower"), TQT_TQOBJECT(this), TQT_SLOT( lowerCurrent() ) );
orderMenu->insertItem( i18n("&To Background"), TQT_TQOBJECT(this), TQT_SLOT( backCurrent() ) );
- KPopupMenu* centerMenu = new KPopupMenu( m_mnuContext );
+ TDEPopupMenu* centerMenu = new TDEPopupMenu( m_mnuContext );
centerMenu->insertItem( i18n("Center &Horizontally"), TQT_TQOBJECT(this), TQT_SLOT( centerHorizontal() ) );
centerMenu->insertItem( i18n("Center &Vertically"), TQT_TQOBJECT(this), TQT_SLOT( centerVertical() ) );
diff --git a/kbarcode/labeleditor.h b/kbarcode/labeleditor.h
index 0702e46..06830f9 100644
--- a/kbarcode/labeleditor.h
+++ b/kbarcode/labeleditor.h
@@ -35,17 +35,17 @@
class BatchPrinter;
class KURL;
-class KAction;
-class KActionMenu;
-class KActionSeparator;
-class KToggleAction;
-class KRecentFilesAction;
-class KToolBarPopupAction;
-class KListBox;
+class TDEAction;
+class TDEActionMenu;
+class TDEActionSeparator;
+class TDEToggleAction;
+class TDERecentFilesAction;
+class TDEToolBarPopupAction;
+class TDEListBox;
class KMenuBar;
-class KPopupMenu;
+class TDEPopupMenu;
class KRuler;
-class KToolBar;
+class TDEToolBar;
class KCommandHistory;
class MyCanvasText;
class MyCanvasRectangle;
@@ -183,52 +183,52 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
KCommandHistory* history;
- KAction* saveAct;
- KAction* saveAsAct;
- KAction* exportAct;
- KAction* descriptionAct;
- KAction* printAct;
- KAction* bcpAct;
- KAction* imgAct;
- KAction* changeSizeAct;
- KAction* deleteAct;
- KAction* editPropAct;
- KAction* barcodeAct;
- KAction* rectAct;
- KAction* circleAct;
- KAction* lineAct;
- KAction* pictureAct;
- KAction* previewAct;
- KAction* textAct;
- KAction* textDataAct;
- KAction* textLineAct;
- KAction* spellAct;
- KAction* cutAct;
- KAction* copyAct;
- KAction* pasteAct;
- KAction* undoAct;
- KAction* redoAct;
- KAction* closeLabelAct;
- KAction* addressBookAct;
- KAction* selectAllAct;
- KAction* deSelectAllAct;
+ TDEAction* saveAct;
+ TDEAction* saveAsAct;
+ TDEAction* exportAct;
+ TDEAction* descriptionAct;
+ TDEAction* printAct;
+ TDEAction* bcpAct;
+ TDEAction* imgAct;
+ TDEAction* changeSizeAct;
+ TDEAction* deleteAct;
+ TDEAction* editPropAct;
+ TDEAction* barcodeAct;
+ TDEAction* rectAct;
+ TDEAction* circleAct;
+ TDEAction* lineAct;
+ TDEAction* pictureAct;
+ TDEAction* previewAct;
+ TDEAction* textAct;
+ TDEAction* textDataAct;
+ TDEAction* textLineAct;
+ TDEAction* spellAct;
+ TDEAction* cutAct;
+ TDEAction* copyAct;
+ TDEAction* pasteAct;
+ TDEAction* undoAct;
+ TDEAction* redoAct;
+ TDEAction* closeLabelAct;
+ TDEAction* addressBookAct;
+ TDEAction* selectAllAct;
+ TDEAction* deSelectAllAct;
/**
* Undo/Redo actins get pluged into this menu
*/
- KPopupMenu* editMenu;
- KPopupMenu* exportMenu;
- KPopupMenu* m_mnuContext;
+ TDEPopupMenu* editMenu;
+ TDEPopupMenu* exportMenu;
+ TDEPopupMenu* m_mnuContext;
- KToolBar* tools;
+ TDEToolBar* tools;
- KToggleAction* gridAct;
+ TDEToggleAction* gridAct;
KComboBox* comboScale;
- KRecentFilesAction* recentAct;
- KActionSeparator* sep;
- KToolBarPopupAction* listAct;
+ TDERecentFilesAction* recentAct;
+ TDEActionSeparator* sep;
+ TDEToolBarPopupAction* listAct;
MyCanvas* c;
MyCanvasView* cv;
@@ -239,7 +239,7 @@ class LabelEditor : public DSMainWindow, public EditorIface, private LabelUtils,
TQString description; // description
TQString filename; // current file
- KListBox* listFields;
+ TDEListBox* listFields;
KPushButton* buttonText;
TQVBoxLayout* pageLayout;
diff --git a/kbarcode/multilineeditdlg.cpp b/kbarcode/multilineeditdlg.cpp
index 9d7b39d..3c43d52 100644
--- a/kbarcode/multilineeditdlg.cpp
+++ b/kbarcode/multilineeditdlg.cpp
@@ -46,9 +46,9 @@ MultiLineEditor::MultiLineEditor( TokenProvider* token, TQWidget *parent, const
editor->setFocus();
TQDockArea* area = new TQDockArea( Qt::Horizontal, TQDockArea::Normal, this );
- toolBar = new KToolBar( area );
- tool2Bar = new KToolBar( area );
- tool3Bar = new KToolBar( area );
+ toolBar = new TDEToolBar( area );
+ tool2Bar = new TDEToolBar( area );
+ tool3Bar = new TDEToolBar( area );
setupActions();
@@ -64,68 +64,68 @@ MultiLineEditor::~MultiLineEditor()
void MultiLineEditor::setupActions()
{
- ac = new KActionCollection( this );
+ ac = new TDEActionCollection( this );
- KAction* action_export = new KAction( i18n("Export"), "fileexport", 0, TQT_TQOBJECT(this), TQT_SLOT( save() ), ac );
+ TDEAction* action_export = new TDEAction( i18n("Export"), "fileexport", 0, TQT_TQOBJECT(this), TQT_SLOT( save() ), ac );
//
// Edit Actions
//
- KAction *action_undo = KStdAction::undo( TQT_TQOBJECT(editor), TQT_SLOT( undo() ), ac );
+ TDEAction *action_undo = KStdAction::undo( TQT_TQOBJECT(editor), TQT_SLOT( undo() ), ac );
action_undo->setEnabled( false );
connect( editor, TQT_SIGNAL( undoAvailable(bool) ), action_undo, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_redo = KStdAction::redo( TQT_TQOBJECT(editor), TQT_SLOT( redo() ), ac );
+ TDEAction *action_redo = KStdAction::redo( TQT_TQOBJECT(editor), TQT_SLOT( redo() ), ac );
action_redo->setEnabled( false );
connect( editor, TQT_SIGNAL( redoAvailable(bool) ), action_redo, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_cut = KStdAction::cut( TQT_TQOBJECT(editor), TQT_SLOT( cut() ), ac );
+ TDEAction *action_cut = KStdAction::cut( TQT_TQOBJECT(editor), TQT_SLOT( cut() ), ac );
action_cut->setEnabled( false );
connect( editor, TQT_SIGNAL( copyAvailable(bool) ), action_cut, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_copy = KStdAction::copy( TQT_TQOBJECT(editor), TQT_SLOT( copy() ), ac );
+ TDEAction *action_copy = KStdAction::copy( TQT_TQOBJECT(editor), TQT_SLOT( copy() ), ac );
action_copy->setEnabled( false );
connect( editor, TQT_SIGNAL( copyAvailable(bool) ), action_copy, TQT_SLOT( setEnabled(bool) ) );
- KAction* action_paste = KStdAction::paste( TQT_TQOBJECT(editor), TQT_SLOT( paste() ), ac );
+ TDEAction* action_paste = KStdAction::paste( TQT_TQOBJECT(editor), TQT_SLOT( paste() ), ac );
//
// Character Formatting
//
- action_bold = new KToggleAction( i18n("&Bold"), "text_bold", CTRL+Key_B, ac, "format_bold" );
+ action_bold = new TDEToggleAction( i18n("&Bold"), "text_bold", CTRL+Key_B, ac, "format_bold" );
connect( action_bold, TQT_SIGNAL( toggled(bool) ), editor, TQT_SLOT( setBold(bool) ) );
- action_italic = new KToggleAction( i18n("&Italic"), "text_italic", CTRL+Key_I, ac, "format_italic" );
+ action_italic = new TDEToggleAction( i18n("&Italic"), "text_italic", CTRL+Key_I, ac, "format_italic" );
connect( action_italic, TQT_SIGNAL( toggled(bool) ), editor, TQT_SLOT( setItalic(bool) ) );
- action_underline = new KToggleAction( i18n("&Underline"), "text_under", CTRL+Key_U, ac, "format_underline" );
+ action_underline = new TDEToggleAction( i18n("&Underline"), "text_under", CTRL+Key_U, ac, "format_underline" );
connect( action_underline, TQT_SIGNAL( toggled(bool) ), editor, TQT_SLOT( setUnderline(bool) ) );
- KAction* action_color = new KAction( i18n("Text &Color..."), "colorpicker", 0, TQT_TQOBJECT(this), TQT_SLOT( formatColor() ), ac, "format_color" );
+ TDEAction* action_color = new TDEAction( i18n("Text &Color..."), "colorpicker", 0, TQT_TQOBJECT(this), TQT_SLOT( formatColor() ), ac, "format_color" );
//
// Font
//
- action_font = new KFontAction( i18n("&Font"), 0, ac, "format_font" );
+ action_font = new TDEFontAction( i18n("&Font"), 0, ac, "format_font" );
connect( action_font, TQT_SIGNAL( activated( const TQString & ) ), editor, TQT_SLOT( setFamily( const TQString & ) ) );
- action_font_size = new KFontSizeAction( i18n("Font &Size"), 0, ac, "format_font_size" );
+ action_font_size = new TDEFontSizeAction( i18n("Font &Size"), 0, ac, "format_font_size" );
connect( action_font_size, TQT_SIGNAL( fontSizeChanged(int) ), editor, TQT_SLOT( setPointSize(int) ) );
//
// Alignment
//
- action_align_left = new KToggleAction( i18n("Align &Left"), "text_left", 0, ac, "format_align_left" );
+ action_align_left = new TDEToggleAction( i18n("Align &Left"), "text_left", 0, ac, "format_align_left" );
connect( action_align_left, TQT_SIGNAL( toggled(bool) ), TQT_TQOBJECT(this), TQT_SLOT( setAlignLeft(bool) ) );
- action_align_center = new KToggleAction( i18n("Align &Center"), "text_center", 0, ac, "format_align_center" );
+ action_align_center = new TDEToggleAction( i18n("Align &Center"), "text_center", 0, ac, "format_align_center" );
connect( action_align_center, TQT_SIGNAL( toggled(bool) ), TQT_TQOBJECT(this), TQT_SLOT( setAlignCenter(bool) ) );
- action_align_right = new KToggleAction( i18n("Align &Right"), "text_right", 0, ac, "format_align_right" );
+ action_align_right = new TDEToggleAction( i18n("Align &Right"), "text_right", 0, ac, "format_align_right" );
connect( action_align_right, TQT_SIGNAL( toggled(bool) ), TQT_TQOBJECT(this), TQT_SLOT( setAlignRight(bool) ) );
- action_align_justify = new KToggleAction( i18n("&Justify"), "text_block", 0, ac, "format_align_justify" );
+ action_align_justify = new TDEToggleAction( i18n("&Justify"), "text_block", 0, ac, "format_align_justify" );
connect( action_align_justify, TQT_SIGNAL( toggled(bool) ), TQT_TQOBJECT(this), TQT_SLOT( setAlignJustify(bool) ) );
action_align_left->setExclusiveGroup( "alignment" );
@@ -133,9 +133,9 @@ void MultiLineEditor::setupActions()
action_align_right->setExclusiveGroup( "alignment" );
action_align_justify->setExclusiveGroup( "alignment" );
- //KAction* action_spell = KStdAction::spelling( this, TQT_SLOT( checkSpelling() ), ac );
+ //TDEAction* action_spell = KStdAction::spelling( this, TQT_SLOT( checkSpelling() ), ac );
- KAction* textDataAct = new KAction( i18n("Insert &Data Field"), "contents", 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewField() ), ac, "text_data_act"); action_export->plug( toolBar );
+ TDEAction* textDataAct = new TDEAction( i18n("Insert &Data Field"), "contents", 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewField() ), ac, "text_data_act"); action_export->plug( toolBar );
toolBar->insertSeparator();
action_undo->plug( toolBar );
diff --git a/kbarcode/multilineeditdlg.h b/kbarcode/multilineeditdlg.h
index ac09d1e..b7943de 100644
--- a/kbarcode/multilineeditdlg.h
+++ b/kbarcode/multilineeditdlg.h
@@ -21,11 +21,11 @@
#include <tqwidget.h>
#include "documentitem.h"
-class KActionCollection;
-class KToggleAction;
-class KFontAction;
-class KFontSizeAction;
-class KToolBar;
+class TDEActionCollection;
+class TDEToggleAction;
+class TDEFontAction;
+class TDEFontSizeAction;
+class TDEToolBar;
class KSpell;
class KSpellConfig;
class DSTextEdit;
@@ -62,23 +62,23 @@ class MultiLineEditor : public TQWidget {
DSTextEdit* editor;
- KActionCollection* ac;
+ TDEActionCollection* ac;
- KToggleAction *action_bold;
- KToggleAction *action_italic;
- KToggleAction *action_underline;
+ TDEToggleAction *action_bold;
+ TDEToggleAction *action_italic;
+ TDEToggleAction *action_underline;
- KFontAction *action_font;
- KFontSizeAction *action_font_size;
+ TDEFontAction *action_font;
+ TDEFontSizeAction *action_font_size;
- KToggleAction *action_align_left;
- KToggleAction *action_align_right;
- KToggleAction *action_align_center;
- KToggleAction *action_align_justify;
+ TDEToggleAction *action_align_left;
+ TDEToggleAction *action_align_right;
+ TDEToggleAction *action_align_center;
+ TDEToggleAction *action_align_justify;
- KToolBar* toolBar;
- KToolBar* tool2Bar;
- KToolBar* tool3Bar;
+ TDEToolBar* toolBar;
+ TDEToolBar* tool2Bar;
+ TDEToolBar* tool3Bar;
KSpell* spell;
};
diff --git a/kbarcode/textlineedit.cpp b/kbarcode/textlineedit.cpp
index b9eca4b..3a1bc79 100644
--- a/kbarcode/textlineedit.cpp
+++ b/kbarcode/textlineedit.cpp
@@ -42,9 +42,9 @@ TextLineEditor::TextLineEditor( TokenProvider* token, TQWidget *parent, const ch
editor->setFocus();
TQDockArea* area = new TQDockArea( Qt::Horizontal, TQDockArea::Normal, this );
- toolBar = new KToolBar( area );
- tool2Bar = new KToolBar( area );
- tool3Bar = new KToolBar( area );
+ toolBar = new TDEToolBar( area );
+ tool2Bar = new TDEToolBar( area );
+ tool3Bar = new TDEToolBar( area );
setupActions();
@@ -65,29 +65,29 @@ TextLineEditor::~TextLineEditor()
void TextLineEditor::setupActions()
{
- ac = new KActionCollection( this );
+ ac = new TDEActionCollection( this );
- KAction *action_undo = KStdAction::undo( TQT_TQOBJECT(editor), TQT_SLOT( undo() ), ac );
+ TDEAction *action_undo = KStdAction::undo( TQT_TQOBJECT(editor), TQT_SLOT( undo() ), ac );
action_undo->setEnabled( false );
connect( editor, TQT_SIGNAL( undoAvailable(bool) ), action_undo, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_redo = KStdAction::redo( TQT_TQOBJECT(editor), TQT_SLOT( redo() ), ac );
+ TDEAction *action_redo = KStdAction::redo( TQT_TQOBJECT(editor), TQT_SLOT( redo() ), ac );
action_redo->setEnabled( false );
connect( editor, TQT_SIGNAL( redoAvailable(bool) ), action_redo, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_cut = KStdAction::cut( TQT_TQOBJECT(editor), TQT_SLOT( cut() ), ac );
+ TDEAction *action_cut = KStdAction::cut( TQT_TQOBJECT(editor), TQT_SLOT( cut() ), ac );
action_cut->setEnabled( false );
connect( editor, TQT_SIGNAL( copyAvailable(bool) ), action_cut, TQT_SLOT( setEnabled(bool) ) );
- KAction *action_copy = KStdAction::copy( TQT_TQOBJECT(editor), TQT_SLOT( copy() ), ac );
+ TDEAction *action_copy = KStdAction::copy( TQT_TQOBJECT(editor), TQT_SLOT( copy() ), ac );
action_copy->setEnabled( false );
connect( editor, TQT_SIGNAL( copyAvailable(bool) ), action_copy, TQT_SLOT( setEnabled(bool) ) );
- KAction* action_paste = KStdAction::paste( TQT_TQOBJECT(editor), TQT_SLOT( paste() ), ac );
+ TDEAction* action_paste = KStdAction::paste( TQT_TQOBJECT(editor), TQT_SLOT( paste() ), ac );
- KAction* textDataAct = new KAction( i18n("Insert &Data Field"), "contents", 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewField() ), ac, "text_data_act");
+ TDEAction* textDataAct = new TDEAction( i18n("Insert &Data Field"), "contents", 0, TQT_TQOBJECT(this), TQT_SLOT( insertNewField() ), ac, "text_data_act");
action_undo->plug( toolBar );
action_redo->plug( toolBar );
diff --git a/kbarcode/textlineedit.h b/kbarcode/textlineedit.h
index 4d23c55..282d22e 100644
--- a/kbarcode/textlineedit.h
+++ b/kbarcode/textlineedit.h
@@ -16,11 +16,11 @@
#include <tqwidget.h>
#include <knuminput.h>
-class KActionCollection;
-class KToggleAction;
-class KFontAction;
-class KFontSizeAction;
-class KToolBar;
+class TDEActionCollection;
+class TDEToggleAction;
+class TDEFontAction;
+class TDEFontSizeAction;
+class TDEToolBar;
class KSpell;
class KSpellConfig;
class KComboBox;
@@ -57,12 +57,12 @@ class TextLineEditor : public TQWidget {
KLineEdit* editor;
- KActionCollection* ac;
+ TDEActionCollection* ac;
KComboBox *action_font_type ;
- KToolBar* toolBar;
- KToolBar* tool2Bar;
- KToolBar* tool3Bar;
+ TDEToolBar* toolBar;
+ TDEToolBar* tool2Bar;
+ TDEToolBar* tool3Bar;
diff --git a/kbarcode/tokendialog.cpp b/kbarcode/tokendialog.cpp
index b936548..c7a5ec8 100644
--- a/kbarcode/tokendialog.cpp
+++ b/kbarcode/tokendialog.cpp
@@ -133,11 +133,11 @@ void TokenDialog::setupStack2Page1()
TQVBox* right = new TQVBox( splitter );
TQLabel* label = new TQLabel( i18n("&Category:"), left );
- category = new KListBox( left );
+ category = new TDEListBox( left );
label->setBuddy( category );
label = new TQLabel( i18n("&Token:"), right );
- allList = new KListView( right );
+ allList = new TDEListView( right );
allList->addColumn( i18n("Token"), 0 );
allList->addColumn( i18n("Description"), 1 );
allList->setColumnWidthMode( 0, TQListView::Maximum );
@@ -172,7 +172,7 @@ void TokenDialog::setupStack2Page2()
{
stack2Page2 = new TQVBox();
- labelList = new KListView( stack2Page2 );
+ labelList = new TDEListView( stack2Page2 );
labelList->addColumn( i18n("Token"), 0 );
labelList->addColumn( i18n("Description"), 1 );
labelList->setColumnWidthMode( 0, TQListView::Maximum );
@@ -192,7 +192,7 @@ void TokenDialog::setupStack2Page3()
editVariable = new KLineEdit( stack2Page3 );
radioVariableExisting = new TQRadioButton( i18n("&Insert an existing custom variable"), stack2Page3 );
- listVariable = new KListBox( stack2Page3 );
+ listVariable = new TDEListBox( stack2Page3 );
radioVariableNew->setChecked( true );
@@ -378,7 +378,7 @@ void TokenDialog::initStackPage2()
if( (*categories)[i].category == cat )
{
for( unsigned int z = 0; z < (*categories)[i].tokens.count(); z++ )
- labelList->insertItem( new KListViewItem( labelList, TQString( "[%1]").arg( (*categories)[i].tokens[z].token ),
+ labelList->insertItem( new TDEListViewItem( labelList, TQString( "[%1]").arg( (*categories)[i].tokens[z].token ),
(*categories)[i].tokens[z].description ) );
break;
@@ -396,7 +396,7 @@ void TokenDialog::categoryChanged( TQListBoxItem* item )
if( item->prev() == 0 )
{
for( i = 0; i < m_tokens.count(); i++ )
- allList->insertItem( new KListViewItem( allList, TQString( "[%1]").arg( m_tokens[i].token ),
+ allList->insertItem( new TDEListViewItem( allList, TQString( "[%1]").arg( m_tokens[i].token ),
m_tokens[i].description ) );
}
else
@@ -406,7 +406,7 @@ void TokenDialog::categoryChanged( TQListBoxItem* item )
if( TokenProvider::captionForCategory( (TokenProvider::ECategories)(*categories)[i].category ) == item->text() )
{
for( unsigned int z = 0; z < (*categories)[i].tokens.count(); z++ )
- allList->insertItem( new KListViewItem( allList, TQString( "[%1]").arg( (*categories)[i].tokens[z].token ),
+ allList->insertItem( new TDEListViewItem( allList, TQString( "[%1]").arg( (*categories)[i].tokens[z].token ),
(*categories)[i].tokens[z].description ) );
break;
@@ -416,7 +416,7 @@ void TokenDialog::categoryChanged( TQListBoxItem* item )
// TODO: comparing by a user visible string cries for bugs!!!
if( item->text() == i18n("Custom Values") )
for( i=0;i<m_custom_tokens.count();i++ )
- allList->insertItem( new KListViewItem( allList, TQString( "[%1]").arg( m_custom_tokens[i] ),
+ allList->insertItem( new TDEListViewItem( allList, TQString( "[%1]").arg( m_custom_tokens[i] ),
i18n("Variable defined by the user for this label.") ) );
}
}
diff --git a/kbarcode/tokendialog.h b/kbarcode/tokendialog.h
index 666e405..35e623a 100644
--- a/kbarcode/tokendialog.h
+++ b/kbarcode/tokendialog.h
@@ -22,8 +22,8 @@
#include "documentitem.h"
#include "tokenprovider.h"
-class KListBox;
-class KListView;
+class TDEListBox;
+class TDEListView;
class TQListBoxItem;
class TQListViewItem;
class KLineEdit;
@@ -95,7 +95,7 @@ class TokenDialog : public KWizard {
TQRadioButton* radioVariableExisting;
KLineEdit* editVariable;
- KListBox* listVariable;
+ TDEListBox* listVariable;
KLineEdit* editQuery;
TQTextBrowser* textQueryResults;
@@ -120,11 +120,11 @@ class TokenDialog : public KWizard {
TQValueList<tToken> m_tokens;
TokenProvider* m_token;
- KListBox* category;
- KListView* allList;
+ TDEListBox* category;
+ TDEListView* allList;
KLineEdit* lineEdit;
- KListView* labelList;
+ TDEListView* labelList;
};
#endif
diff --git a/kbarcode/kactionmap.h b/kbarcode/kactionmap.h
index 5094172..3245785 100644
--- a/kbarcode/kactionmap.h
+++ b/kbarcode/kactionmap.h
@@ -22,19 +22,19 @@
#include <tdeversion.h>
#include <kdialogbase.h>
-class KActionCollection;
-class KActionMap;
+class TDEActionCollection;
+class TDEActionMap;
#if TDE_VERSION >= 0x030500
-class KListViewSearchLineWidget;
+class TDEListViewSearchLineWidget;
#endif
-class KListView;
+class TDEListView;
class TQListViewItem;
/** Open a simple dialog containing an action map.
*/
-class KActionMapDlg : public KDialogBase {
+class TDEActionMapDlg : public KDialogBase {
public:
- KActionMapDlg( KActionCollection* actions, TQWidget* parent = NULL, const char* name = NULL );
+ TDEActionMapDlg( TDEActionCollection* actions, TQWidget* parent = NULL, const char* name = NULL );
/** Call this function whenever you changed the enabled/disalbed state of an action
* in your application.
@@ -42,7 +42,7 @@ class KActionMapDlg : public KDialogBase {
void updateEnabledState();
private:
- KActionMap* m_map;
+ TDEActionMap* m_map;
};
/**
@@ -66,17 +66,17 @@ class KActionMapDlg : public KDialogBase {
* grayed out and cannot be clicked. The dialog is modeless so that
* it can always be open and the normal usage of the application is not disturbed.
*/
-class KActionMap : public TQWidget {
+class TDEActionMap : public TQWidget {
Q_OBJECT
public:
/** Creates a new KActionMap widget
* @param action all actions from this KActionCollection are displayed.
* @param parent the parent
* @param name the name
*/
- KActionMap( KActionCollection* actions, TQWidget* parent = NULL, const char* name = NULL );
- ~KActionMap();
+ TDEActionMap( TDEActionCollection* actions, TQWidget* parent = NULL, const char* name = NULL );
+ ~TDEActionMap();
public slots:
/** Call this function whenever you changed the enabled/disalbed state of an action
@@ -89,10 +89,10 @@ class KActionMap : public TQWidget {
void slotExecuteAction( TQListViewItem* item );
private:
- KActionCollection* m_actions;
- KListView* m_listView;
+ TDEActionCollection* m_actions;
+ TDEListView* m_listView;
#if TDE_VERSION >= 0x030500
- KListViewSearchLineWidget* m_searchLine;
+ TDEListViewSearchLineWidget* m_searchLine;
#endif
bool m_showMenuTree;
@@ -66,17 +66,17 @@ class KActionMapDlg : public KDialogBase {
Q_OBJECT
public:
- /** Creates a new KActionMap widget
- * @param action all actions from this KActionCollection are displayed.
+ /** Creates a new TDEActionMap widget
+ * @param action all actions from this TDEActionCollection are displayed.
* @param parent the parent
* @param name the name